summaryrefslogtreecommitdiffstats
path: root/kbackgammon/engines/fibs
diff options
context:
space:
mode:
Diffstat (limited to 'kbackgammon/engines/fibs')
-rw-r--r--kbackgammon/engines/fibs/kbgfibs.cpp102
-rw-r--r--kbackgammon/engines/fibs/kbgfibs.h8
-rw-r--r--kbackgammon/engines/fibs/kbgfibschat.cpp50
-rw-r--r--kbackgammon/engines/fibs/kbginvite.cpp6
-rw-r--r--kbackgammon/engines/fibs/kplayerlist.cpp48
-rw-r--r--kbackgammon/engines/fibs/kplayerlist.h6
6 files changed, 110 insertions, 110 deletions
diff --git a/kbackgammon/engines/fibs/kbgfibs.h b/kbackgammon/engines/fibs/kbgfibs.h
index 24555ef2..db79ce51 100644
--- a/kbackgammon/engines/fibs/kbgfibs.h
+++ b/kbackgammon/engines/fibs/kbgfibs.h
@@ -175,7 +175,7 @@ signals:
void fibsConnectionClosed();
- void changePlayertqStatus(const TQString &, int, bool);
+ void changePlayerStatus(const TQString &, int, bool);
void chatMessage(const TQString &msg);
@@ -199,7 +199,7 @@ private:
TQString currBoard, caption;
- //KBgtqStatus *currBoard
+ //KBgStatus *currBoard
//KBgFIBSBoard *boardHandler;
TQStringList invitations;
@@ -400,10 +400,10 @@ protected slots:
protected:
- enum RxtqStatus {RxIgnore, RxConnect, RxWhois, RxMotd, RxRating,
+ enum RxStatus {RxIgnore, RxConnect, RxWhois, RxMotd, RxRating,
RxNewLogin, RxGoodbye, RxNormal};
- int rxtqStatus, rxCount;
+ int rxStatus, rxCount;
TQString rxCollect;
diff --git a/kbackgammon/engines/fibs/kbgfibschat.cpp b/kbackgammon/engines/fibs/kbgfibschat.cpp
index c3490cec..bae73d46 100644
--- a/kbackgammon/engines/fibs/kbgfibschat.cpp
+++ b/kbackgammon/engines/fibs/kbgfibschat.cpp
@@ -28,17 +28,17 @@
#include <tqstring.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqpopupmenu.h>
#include <tqregexp.h>
#include <tqfont.h>
#include <tqwhatsthis.h>
#include <tqdatetime.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <tqsimplerichtext.h>
#include <tqregion.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqpainter.h>
#include <tqpoint.h>
#include <tqlistbox.h>
@@ -123,7 +123,7 @@ protected:
*/
virtual void paint(TQPainter *p)
{
- t->draw(p, 1, 1, TQRegion(p->viewport()), w->tqcolorGroup());
+ t->draw(p, 1, 1, TQRegion(p->viewport()), w->colorGroup());
}
private:
@@ -200,7 +200,7 @@ KBgChat::KBgChat(TQWidget *parent, const char *name)
d->mInvt = new TQPopupMenu();
setAutoAddMessages(false); // we get an echo from FIBS
- setFromNickname(i18n("%1 user").tqarg(PROG_NAME));
+ setFromNickname(i18n("%1 user").arg(PROG_NAME));
if (!addSendingEntry(i18n("Kibitz to watchers and players"), CLIP_YOU_KIBITZ))
kdDebug(10500) << "adding kibitz" << endl;
@@ -450,7 +450,7 @@ void KBgChat::startGame(const TQString &name)
if (!id) {
id = new int(nextId());
d->mName2ID->insert(name, id);
- addSendingEntry(i18n("Talk to %1").tqarg(name), *id);
+ addSendingEntry(i18n("Talk to %1").arg(name), *id);
}
setSendingEntry(CLIP_YOU_KIBITZ);
}
@@ -476,7 +476,7 @@ void KBgChat::fibsTalk(const TQString &name)
if (!id) {
id = new int(nextId());
d->mName2ID->insert(name, id);
- addSendingEntry(i18n("Talk to %1").tqarg(name), *id);
+ addSendingEntry(i18n("Talk to %1").arg(name), *id);
}
setSendingEntry(*id);
}
@@ -549,7 +549,7 @@ void KBgChat::handleData(const TQString &msg)
switch (cmd) {
case CLIP_SAYS:
if (!d->mGag.contains(user)) {
- cMsg = i18n("<u>%1 tells you:</u> %2").tqarg(user).tqarg(cMsg.replace(TQRegExp("^" + user), ""));
+ cMsg = i18n("<u>%1 tells you:</u> %2").arg(user).arg(cMsg.replace(TQRegExp("^" + user), ""));
cMsg = "<font color=\"red\">" + cMsg + "</font>";
emit personalMessage(cMsg);
} else
@@ -558,7 +558,7 @@ void KBgChat::handleData(const TQString &msg)
case CLIP_SHOUTS:
if ((!((KToggleAction *)d->mAct[KBgChatPrivate::Silent])->isChecked()) && (!d->mGag.contains(user))) {
- cMsg = i18n("<u>%1 shouts:</u> %2").tqarg(user).tqarg(cMsg.replace(TQRegExp("^" + user), ""));
+ cMsg = i18n("<u>%1 shouts:</u> %2").arg(user).arg(cMsg.replace(TQRegExp("^" + user), ""));
cMsg = "<font color=\"black\">" + cMsg + "</font>";
} else
cMsg = "";
@@ -566,7 +566,7 @@ void KBgChat::handleData(const TQString &msg)
case CLIP_WHISPERS:
if (!d->mGag.contains(user)) {
- cMsg = i18n("<u>%1 whispers:</u> %2").tqarg(user).tqarg(cMsg.replace(TQRegExp("^" + user), ""));
+ cMsg = i18n("<u>%1 whispers:</u> %2").arg(user).arg(cMsg.replace(TQRegExp("^" + user), ""));
cMsg = "<font color=\"red\">" + cMsg + "</font>";
emit personalMessage(cMsg);
} else
@@ -575,7 +575,7 @@ void KBgChat::handleData(const TQString &msg)
case CLIP_KIBITZES:
if (!d->mGag.contains(user)) {
- cMsg = i18n("<u>%1 kibitzes:</u> %2").tqarg(user).tqarg(cMsg.replace(TQRegExp("^" + user), ""));
+ cMsg = i18n("<u>%1 kibitzes:</u> %2").arg(user).arg(cMsg.replace(TQRegExp("^" + user), ""));
cMsg = "<font color=\"red\">" + cMsg + "</font>";
emit personalMessage(cMsg);
} else
@@ -583,28 +583,28 @@ void KBgChat::handleData(const TQString &msg)
break;
case CLIP_YOU_SAY:
- cMsg = i18n("<u>You tell %1:</u> %2").tqarg(user).tqarg(cMsg.replace(TQRegExp("^" + user), ""));
+ cMsg = i18n("<u>You tell %1:</u> %2").arg(user).arg(cMsg.replace(TQRegExp("^" + user), ""));
cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
break;
case CLIP_YOU_SHOUT:
- cMsg = i18n("<u>You shout:</u> %1").tqarg(cMsg);
+ cMsg = i18n("<u>You shout:</u> %1").arg(cMsg);
cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
break;
case CLIP_YOU_WHISPER:
- cMsg = i18n("<u>You whisper:</u> %1").tqarg(cMsg);
+ cMsg = i18n("<u>You whisper:</u> %1").arg(cMsg);
cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
break;
case CLIP_YOU_KIBITZ:
- cMsg = i18n("<u>You kibitz:</u> %1").tqarg(cMsg);
+ cMsg = i18n("<u>You kibitz:</u> %1").arg(cMsg);
cMsg = "<font color=\"darkgreen\">" + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
@@ -615,21 +615,21 @@ void KBgChat::handleData(const TQString &msg)
cMsg.remove(0, cMsg.find(' ')+1);
date.setTime_t(cMsg.left(cMsg.find(' ')+1).toUInt());
cMsg.remove(0, cMsg.find(' '));
- cMsg = i18n("<u>User %1 left a message at %2</u>: %3").tqarg(user).tqarg(date.toString()).tqarg(cMsg);
+ cMsg = i18n("<u>User %1 left a message at %2</u>: %3").arg(user).arg(date.toString()).arg(cMsg);
cMsg = "<font color=\"red\">" + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
break;
case CLIP_MESSAGE_DELIVERED:
- cMsg = i18n("Your message for %1 has been delivered.").tqarg(user);
+ cMsg = i18n("Your message for %1 has been delivered.").arg(user);
cMsg = TQString("<font color=\"darkgreen\">") + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
break;
case CLIP_MESSAGE_SAVED:
- cMsg = i18n("Your message for %1 has been saved.").tqarg(user);
+ cMsg = i18n("Your message for %1 has been saved.").arg(user);
cMsg = TQString("<font color=\"darkgreen\">") + cMsg + "</font>";
emit personalMessage(cMsg);
user = TQString();
@@ -683,22 +683,22 @@ void KBgChat::contextMenu(TQListBoxItem *i, const TQPoint &p)
*/
if (!d->mName[0].isNull()) {
- d->mAct[KBgChatPrivate::Talk]->setText(i18n("Talk to %1").tqarg(d->mName[0]));
+ d->mAct[KBgChatPrivate::Talk]->setText(i18n("Talk to %1").arg(d->mName[0]));
d->mAct[KBgChatPrivate::Talk]->plug(d->mChat);
- d->mAct[KBgChatPrivate::Inquire]->setText(i18n("Info on %1").tqarg(d->mName[0]));
+ d->mAct[KBgChatPrivate::Inquire]->setText(i18n("Info on %1").arg(d->mName[0]));
d->mAct[KBgChatPrivate::Inquire]->plug(d->mChat);
// invite menu is always the same
- d->mChat->insertItem(i18n("Invite %1").tqarg(d->mName[0]), d->mInvt);
+ d->mChat->insertItem(i18n("Invite %1").arg(d->mName[0]), d->mInvt);
d->mChat->insertSeparator();
if (d->mGag.contains(d->mName[0]) <= 0) {
- d->mAct[KBgChatPrivate::Gag]->setText(i18n("Gag %1").tqarg(d->mName[0]));
+ d->mAct[KBgChatPrivate::Gag]->setText(i18n("Gag %1").arg(d->mName[0]));
d->mAct[KBgChatPrivate::Gag]->plug(d->mChat);
} else {
- d->mAct[KBgChatPrivate::Ungag]->setText(i18n("Ungag %1").tqarg(d->mName[0]));
+ d->mAct[KBgChatPrivate::Ungag]->setText(i18n("Ungag %1").arg(d->mName[0]));
d->mAct[KBgChatPrivate::Ungag]->plug(d->mChat);
}
}
@@ -741,7 +741,7 @@ void KBgChat::slotGag()
d->mGag.append(d->mName[0]);
TQString msg("<font color=\"blue\">");
- msg += i18n("You won't hear what %1 says and shouts.").tqarg(d->mName[0]);
+ msg += i18n("You won't hear what %1 says and shouts.").arg(d->mName[0]);
msg += "</font>";
addMessage(TQString(), msg);
@@ -763,7 +763,7 @@ void KBgChat::slotUngag()
d->mGag.remove(d->mName[0]);
TQString msg("<font color=\"blue\">");
- msg += i18n("You will again hear what %1 says and shouts.").tqarg(d->mName[0]);
+ msg += i18n("You will again hear what %1 says and shouts.").arg(d->mName[0]);
msg += "</font>";
addMessage(TQString(), msg);
diff --git a/kbackgammon/engines/fibs/kbginvite.cpp b/kbackgammon/engines/fibs/kbginvite.cpp
index 3870a6d2..532cb18a 100644
--- a/kbackgammon/engines/fibs/kbginvite.cpp
+++ b/kbackgammon/engines/fibs/kbginvite.cpp
@@ -25,7 +25,7 @@
#include "kbginvite.moc"
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqframe.h>
#include <tqspinbox.h>
#include <tqstring.h>
@@ -103,9 +103,9 @@ KBgInvite::KBgInvite(const char *name)
* Adjust widget sizes and resize the dialog
*/
KDialog::resizeLayout(this, marginHint(), spacingHint());
- setMinimumSize(tqchildrenRect().size());
+ setMinimumSize(childrenRect().size());
vbox->activate();
- resize(tqminimumSize());
+ resize(minimumSize());
/*
* Set focus and default buttons
diff --git a/kbackgammon/engines/fibs/kplayerlist.cpp b/kbackgammon/engines/fibs/kplayerlist.cpp
index 62fb9a95..25a169b5 100644
--- a/kbackgammon/engines/fibs/kplayerlist.cpp
+++ b/kbackgammon/engines/fibs/kplayerlist.cpp
@@ -24,7 +24,7 @@
#include "kplayerlist.moc"
#include "kplayerlist.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqiconset.h>
#include <tqgroupbox.h>
#include <tqpopupmenu.h>
@@ -101,7 +101,7 @@ public:
case KFibsPlayerList::Watches:
case KFibsPlayerList::Client:
case KFibsPlayerList::Email:
- case KFibsPlayerList::tqStatus:
+ case KFibsPlayerList::Status:
case KFibsPlayerList::Host:
s = s.lower();
break;
@@ -175,7 +175,7 @@ public:
/*
* Short abbreviations for Blind, Ready, and Away.
*/
- TQString mAbrv[KFibsPlayerList::MaxtqStatus];
+ TQString mAbrv[KFibsPlayerList::MaxStatus];
/*
* Name of the last selected player - for internal purposes
@@ -218,7 +218,7 @@ KFibsPlayerList::KFibsPlayerList(TQWidget *parent, const char *name)
d->mCol[Player]->name = i18n("Player");
d->mCol[Opponent]->name = i18n("Opponent");
d->mCol[Watches]->name = i18n("Watches");
- d->mCol[tqStatus]->name = i18n("Status");
+ d->mCol[Status]->name = i18n("Status");
d->mCol[Rating]->name = i18n("Rating");
d->mCol[Experience]->name = i18n("Exp.");
d->mCol[Idle]->name = i18n("Idle");
@@ -231,7 +231,7 @@ KFibsPlayerList::KFibsPlayerList(TQWidget *parent, const char *name)
d->mCol[Player]->key = "player";
d->mCol[Opponent]->key = "opponent";
d->mCol[Watches]->key = "watches";
- d->mCol[tqStatus]->key = "status";
+ d->mCol[Status]->key = "status";
d->mCol[Rating]->key = "rating";
d->mCol[Experience]->key = "experience";
d->mCol[Idle]->key = "idle";
@@ -469,7 +469,7 @@ void KFibsPlayerList::getSetupPages(KTabCtl *nb, int space)
gl = new TQGridLayout(gbl, LVEnd, 2, 20);
gl->addWidget(lb, 0, 0);
- // two column tqlayout....
+ // two column layout....
for (i = 1; i < LVEnd/2; i++) {
gl->addWidget(d->mCol[2*i-1]->cb, i, 0);
gl->addWidget(d->mCol[2*i ]->cb, i, 1);
@@ -569,12 +569,12 @@ void KFibsPlayerList::showContextMenu(KListView *, TQListViewItem *i, const TQPo
*/
d->mUser = (i ? i->text(Player) : TQString());
- d->mAct[KFibsPlayerListPrivate::Info ]->setText(i18n("Info on %1" ).tqarg(d->mUser));
- d->mAct[KFibsPlayerListPrivate::Talk ]->setText(i18n("Talk to %1" ).tqarg(d->mUser));
- d->mAct[KFibsPlayerListPrivate::Mail ]->setText(i18n("Email to %1").tqarg(d->mUser));
- d->mAct[KFibsPlayerListPrivate::Look ]->setText(i18n("Look at %1" ).tqarg(d->mUser));
- d->mAct[KFibsPlayerListPrivate::Watch ]->setText(i18n("Watch %1" ).tqarg(d->mUser));
- d->mAct[KFibsPlayerListPrivate::Update]->setText(i18n("Update %1" ).tqarg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Info ]->setText(i18n("Info on %1" ).arg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Talk ]->setText(i18n("Talk to %1" ).arg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Mail ]->setText(i18n("Email to %1").arg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Look ]->setText(i18n("Look at %1" ).arg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Watch ]->setText(i18n("Watch %1" ).arg(d->mUser));
+ d->mAct[KFibsPlayerListPrivate::Update]->setText(i18n("Update %1" ).arg(d->mUser));
d->mAct[KFibsPlayerListPrivate::Info ]->setEnabled(i);
d->mAct[KFibsPlayerListPrivate::Talk ]->setEnabled(i);
@@ -587,15 +587,15 @@ void KFibsPlayerList::showContextMenu(KListView *, TQListViewItem *i, const TQPo
d->mAct[KFibsPlayerListPrivate::Unwatch]->setEnabled(d->mWatch);
d->mPm[0]->setItemEnabled(d->mInID, i && d->mName != d->mUser);
- d->mPm[0]->changeItem(d->mInID, i18n("Invite %1").tqarg(d->mUser));
+ d->mPm[0]->changeItem(d->mInID, i18n("Invite %1").arg(d->mUser));
d->mMail = (i && d->mCol[Email]->show ? i->text(d->mCol[Email]->index) : TQString());
d->mAct[KFibsPlayerListPrivate::Mail]->setEnabled(!d->mMail.isEmpty());
- if (i && d->mCol[tqStatus]->show)
+ if (i && d->mCol[Status]->show)
d->mAct[KFibsPlayerListPrivate::BlindAct]->setText
- ((i->text(d->mCol[tqStatus]->index).contains(d->mAbrv[Blind])) ?
- i18n("Unblind %1").tqarg(d->mUser) : i18n("Blind %1").tqarg(d->mUser));
+ ((i->text(d->mCol[Status]->index).contains(d->mAbrv[Blind])) ?
+ i18n("Unblind %1").arg(d->mUser) : i18n("Blind %1").arg(d->mUser));
else
d->mAct[KFibsPlayerListPrivate::BlindAct]->setText(i18n("Blind"));
@@ -721,7 +721,7 @@ void KFibsPlayerList::changePlayer(const TQString &line)
TQDateTime fromEpoch;
TQString str_entry[LVEnd], tmp;
- entry[tqStatus][0] = '\0';
+ entry[Status][0] = '\0';
// the line comes from FIBS and is 7 bit ASCII
sscanf(line.latin1(), "%99s %99s %99s %1s %1s %99s %99s %99s %99s %99s %99s %99s", entry[Player], entry[Opponent],
@@ -738,9 +738,9 @@ void KFibsPlayerList::changePlayer(const TQString &line)
if ((str_entry[j] = entry[j]) == "-")
str_entry[j] = "";
}
- str_entry[tqStatus].replace(Ready, 1, ready[0] == '0' ? "-" : d->mAbrv[Ready]);
- str_entry[tqStatus].replace(Away, 1, away [0] == '0' ? "-" : d->mAbrv[Away ]);
- str_entry[tqStatus].replace(Blind, 1, "-");
+ str_entry[Status].replace(Ready, 1, ready[0] == '0' ? "-" : d->mAbrv[Ready]);
+ str_entry[Status].replace(Away, 1, away [0] == '0' ? "-" : d->mAbrv[Away ]);
+ str_entry[Status].replace(Blind, 1, "-");
// disable drawing until the end of update
setUpdatesEnabled(false);
@@ -771,7 +771,7 @@ void KFibsPlayerList::changePlayer(const TQString &line)
found:
// getting here means the player is in the list - update private status
- str_entry[tqStatus].replace(Blind,1,i->text(tqStatus).contains
+ str_entry[Status].replace(Blind,1,i->text(Status).contains
(d->mAbrv[Blind]) ? d->mAbrv[Blind] : "-");
update:
@@ -808,7 +808,7 @@ void KFibsPlayerList::deletePlayer(const TQString &player)
/*
* Set/Unset the status stat in the corresponding column of the list
*/
-void KFibsPlayerList::changePlayertqStatus(const TQString &player, int stat, bool flag)
+void KFibsPlayerList::changePlayerStatus(const TQString &player, int stat, bool flag)
{
TQListViewItem *i = 0;
@@ -827,7 +827,7 @@ void KFibsPlayerList::changePlayertqStatus(const TQString &player, int stat, boo
/*
* Update the status flag
*/
- i->setText(tqStatus, i->text(tqStatus).replace(stat, 1, (flag) ? d->mAbrv[stat] : "-"));
+ i->setText(Status, i->text(Status).replace(stat, 1, (flag) ? d->mAbrv[stat] : "-"));
}
@@ -886,7 +886,7 @@ void KFibsPlayerList::setName(const TQString &name)
*/
void KFibsPlayerList::updateCaption()
{
- setCaption(i18n("Player List - %1 - %2/%3").tqarg(childCount()).tqarg(d->mCount[0]).tqarg(d->mCount[1]));
+ setCaption(i18n("Player List - %1 - %2/%3").arg(childCount()).arg(d->mCount[0]).arg(d->mCount[1]));
}
/*
diff --git a/kbackgammon/engines/fibs/kplayerlist.h b/kbackgammon/engines/fibs/kplayerlist.h
index 793e1b39..63724e06 100644
--- a/kbackgammon/engines/fibs/kplayerlist.h
+++ b/kbackgammon/engines/fibs/kplayerlist.h
@@ -53,12 +53,12 @@ public:
/**
* Enumerate player status
*/
- enum PtqStatus {Ready, Away, Blind, MaxtqStatus};
+ enum PStatus {Ready, Away, Blind, MaxStatus};
/**
* Enumerate the different columns of the list
*/
- enum {Player, Opponent, Watches, tqStatus, Rating, Experience,
+ enum {Player, Opponent, Watches, Status, Rating, Experience,
Idle, Time, Host, Client, Email, LVEnd};
/**
@@ -111,7 +111,7 @@ public slots:
/**
* Change the status of a player
*/
- void changePlayertqStatus(const TQString &player, int stat, bool flag);
+ void changePlayerStatus(const TQString &player, int stat, bool flag);
/**
* Fills the playerlist page into the notebook
diff --git a/kbackgammon/engines/fibs/kbgfibs.cpp b/kbackgammon/engines/fibs/kbgfibs.cpp
index 57eb6666..d56e633c 100644
--- a/kbackgammon/engines/fibs/kbgfibs.cpp
+++ b/kbackgammon/engines/fibs/kbgfibs.cpp
@@ -39,7 +39,7 @@
#include <kconfig.h>
#include <tqtimer.h>
#include <tqcheckbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqstring.h>
#include <tqsocket.h>
#include <tqpopupmenu.h>
@@ -81,7 +81,7 @@ void KBgEngineFIBS::start()
// == configuration handling ===================================================
/*
- * Restore settings and ask tqchildren to do the same
+ * Restore settings and ask children to do the same
*/
void KBgEngineFIBS::readConfig()
{
@@ -110,7 +110,7 @@ void KBgEngineFIBS::readConfig()
autoMsg[MsgLos] = config->readEntry("msg-los", "");
autoMsg[MsgWin] = config->readEntry("msg-win", "");
- // ask the tqchildren to read their config options
+ // ask the children to read their config options
playerlist->readConfig();
chatWindow->readConfig();
}
@@ -145,7 +145,7 @@ void KBgEngineFIBS::saveConfig()
config->writeEntry("msg-los", autoMsg[MsgLos]);
config->writeEntry("msg-win", autoMsg[MsgWin]);
- // ask the tqchildren to read their config options
+ // ask the children to read their config options
playerlist->saveConfig();
chatWindow->saveConfig();
}
@@ -343,7 +343,7 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
TQWhatsThis::add(cbk, i18n("Usually, FIBS drops the connection after one hour of inactivity. When "
"you check this box, %1 will try to keep the connection alive, even "
"if you are not actually playing or chatting. Use this with caution "
- "if you do not have flat-rate Internet access.").tqarg(PROG_NAME));
+ "if you do not have flat-rate Internet access.").arg(PROG_NAME));
cbk->setChecked(keepalive);
@@ -357,7 +357,7 @@ void KBgEngineFIBS::getSetupPages(KDialogBase *nb)
tc->addTab(w, i18n("&Connection"));
/*
- * Ask tqchildren for settings
+ * Ask children for settings
*/
chatWindow->getSetupPages(tc, nb->spacingHint());
playerlist->getSetupPages(tc, nb->spacingHint());
@@ -431,28 +431,28 @@ void KBgEngineFIBS::changeJoin(const TQString &info)
TQString text, menu;
if ((*it).contains(TQRegExp(" r$"))) {
- menu = i18n("R means resume", "%1 (R)").tqarg(name);
+ menu = i18n("R means resume", "%1 (R)").arg(name);
text = i18n("%1 (experience %2, rating %3) wants to resume a saved match with you. "
"If you want to play, use the corresponding menu entry to join (or type "
- "'join %4').").tqarg(name).tqarg(expi_s).tqarg(rate_s).tqarg(name);
+ "'join %4').").arg(name).arg(expi_s).arg(rate_s).arg(name);
KNotifyClient::event("invitation", i18n("%1 wants to resume a saved match with you").
arg(name));
} else if ((*it).contains(TQRegExp(" u$"))) {
- menu = i18n("U means unlimited", "%1 (U)").tqarg(name);
+ menu = i18n("U means unlimited", "%1 (U)").arg(name);
text = i18n("%1 (experience %2, rating %3) wants to play an unlimited match with you. "
"If you want to play, use the corresponding menu entry to join (or type "
- "'join %4').").tqarg(name).tqarg(expi_s).tqarg(rate_s).tqarg(name);
+ "'join %4').").arg(name).arg(expi_s).arg(rate_s).arg(name);
KNotifyClient::event("invitation", i18n("%1 has invited you to an unlimited match").
arg(name));
} else {
TQString len = (*it).right((*it).length() - name.length() - 1);
menu = i18n("If the format of the (U) and (R) strings is changed, it should also be changed here",
- "%1 (%2)").tqarg(name).tqarg(len);
+ "%1 (%2)").arg(name).arg(len);
text = i18n("%1 (experience %2, rating %3) wants to play a %4 point match with you. "
"If you want to play, use the corresponding menu entry to join (or type "
- "'join %5').").tqarg(name).tqarg(expi_s).tqarg(rate_s).tqarg(len).tqarg(name);
+ "'join %5').").arg(name).arg(expi_s).arg(rate_s).arg(len).arg(name);
KNotifyClient::event("invitation", i18n("%1 has invited you for a %2 point match").
- tqarg(name).tqarg(len));
+ arg(name).arg(len));
}
emit serverString("rawwho " + name); // this avoids a race
if (whoisInvite) {
@@ -877,7 +877,7 @@ void KBgEngineFIBS::connectFIBS()
/*
* Connect
*/
- emit infoText(i18n("Looking up %1").tqarg(infoFIBS[FIBSHost]));
+ emit infoText(i18n("Looking up %1").arg(infoFIBS[FIBSHost]));
connection->connectToHost(infoFIBS[FIBSHost], infoFIBS[FIBSPort].toUShort());
return;
@@ -888,7 +888,7 @@ void KBgEngineFIBS::connectFIBS()
*/
void KBgEngineFIBS::hostFound()
{
- emit infoText(i18n("Connecting to %1").tqarg(infoFIBS[FIBSHost]));
+ emit infoText(i18n("Connecting to %1").arg(infoFIBS[FIBSHost]));
}
/*
@@ -947,7 +947,7 @@ void KBgEngineFIBS::connected()
/*
* Initialize the rx state machine
*/
- rxtqStatus = RxConnect;
+ rxStatus = RxConnect;
rxCollect = "";
/*
@@ -992,7 +992,7 @@ void KBgEngineFIBS::newAccount()
if (!queryConnection(true))
return;
- rxtqStatus = RxNewLogin;
+ rxStatus = RxNewLogin;
rxCollect = "";
login = false;
connectFIBS();
@@ -1077,12 +1077,12 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
text = i18n("Enter the login you would like to use on the server %1. The login may not\n"
"contain spaces or colons. If the login you choose is not available, you'll later be\n"
- "given the opportunity to pick another one.\n\n").tqarg(infoFIBS[FIBSHost]);
+ "given the opportunity to pick another one.\n\n").arg(infoFIBS[FIBSHost]);
else
text = i18n("Enter your login on the server %1. If you don't have a login, you\n"
- "should create one using the corresponding menu option.\n\n").tqarg(infoFIBS[FIBSHost]);
+ "should create one using the corresponding menu option.\n\n").arg(infoFIBS[FIBSHost]);
first = true;
@@ -1107,12 +1107,12 @@ bool KBgEngineFIBS::queryConnection(const bool newlogin)
text = i18n("Enter the password you would like to use with the login %1\n"
"on the server %2. It may not contain colons.\n\n").
- tqarg(infoFIBS[FIBSUser]).tqarg(infoFIBS[FIBSHost]);
+ arg(infoFIBS[FIBSUser]).arg(infoFIBS[FIBSHost]);
else
text = i18n("Enter the password for the login %1 on the server %2.\n\n").
- tqarg(infoFIBS[FIBSUser]).tqarg(infoFIBS[FIBSHost]);
+ arg(infoFIBS[FIBSUser]).arg(infoFIBS[FIBSHost]);
first = true;
do {
@@ -1289,7 +1289,7 @@ void KBgEngineFIBS::handleServerData(TQString &line)
*/
line.replace(pat[TabChar], " ");
- switch (rxtqStatus) {
+ switch (rxStatus) {
case RxConnect:
handleMessageConnect(line, rawline);
@@ -1345,7 +1345,7 @@ void KBgEngineFIBS::handleMessageWhois(const TQString &line)
{
rxCollect += "<br>&nbsp;&nbsp;&nbsp;&nbsp;" + line;
if (line.contains(pat[WhoisE1]) || line.contains(pat[WhoisE2])) {
- rxtqStatus = RxNormal;
+ rxStatus = RxNormal;
emit infoText("<font color=\"darkgreen\">" + rxCollect + "<br></font>");
}
}
@@ -1358,7 +1358,7 @@ void KBgEngineFIBS::handleMessageRating(const TQString &line)
rxCollect += "<br>" + line;
if (line.contains(pat[EndRate]) && ++rxCount == 2) {
emit infoText("<font color=\"blue\">" + rxCollect + "<br></font>");
- rxtqStatus = RxNormal;
+ rxStatus = RxNormal;
}
}
@@ -1368,7 +1368,7 @@ void KBgEngineFIBS::handleMessageRating(const TQString &line)
void KBgEngineFIBS::handleMessageMotd(const TQString &line)
{
if (line.contains(pat[MotdEnd])) {
- rxtqStatus = RxNormal;
+ rxStatus = RxNormal;
emit infoText("<font color=\"blue\"><pre>" + rxCollect + "</pre></font>");
/*
* just to be on the safe side, we set the value of boardstyle.
@@ -1398,7 +1398,7 @@ void KBgEngineFIBS::handleMessageConnect(const TQString &line, const TQString &r
* This can only happen if the password/login is wrong.
*/
if (rxCollect.isEmpty()) {
- rxtqStatus = RxIgnore;
+ rxStatus = RxIgnore;
int ret = KMessageBox::warningContinueCancel
((TQWidget *)parent(), i18n("There was a problem with "
"your login and password. "
@@ -1411,9 +1411,9 @@ void KBgEngineFIBS::handleMessageConnect(const TQString &line, const TQString &r
infoFIBS[FIBSUser] = "";
infoFIBS[FIBSPswd] = "";
login = true;
- connectFIBS(); // will reset the rxtqStatus
+ connectFIBS(); // will reset the rxStatus
} else {
- rxtqStatus = RxConnect;
+ rxStatus = RxConnect;
emit serverString("");
emit serverString("");
}
@@ -1435,7 +1435,7 @@ void KBgEngineFIBS::handleMessageConnect(const TQString &line, const TQString &r
int words = sscanf (line.latin1(), "%255s%255s%li%255s", p[0], p[1], &tmp, p[2]);
if (words >= 4) {
TQDateTime d; d.setTime_t(tmp);
- TQString text = i18n("%1, last logged in from %2 at %3.").tqarg(p[1]).tqarg(p[2]).tqarg(d.toString());
+ TQString text = i18n("%1, last logged in from %2 at %3.").arg(p[1]).arg(p[2]).arg(d.toString());
emit infoText("<hr><br>" + text);
playerlist->setName(p[1]);
}
@@ -1473,7 +1473,7 @@ void KBgEngineFIBS::handleMessageConnect(const TQString &line, const TQString &r
*/
if (line.contains(pat[OwnInfo])) {
- rxtqStatus = RxNormal;
+ rxStatus = RxNormal;
int fibsOptions[NumFIBSOpt];
@@ -1538,7 +1538,7 @@ void KBgEngineFIBS::handleMessageConnect(const TQString &line, const TQString &r
* The beginning of a new login procedure starts starts here
*/
if (line.contains(pat[OneName])) {
- rxtqStatus = RxNewLogin;
+ rxStatus = RxNewLogin;
emit infoText(TQString("<font color=\"red\">") + rxCollect + "</font>");
rxCollect = "";
TQString tmp = rawline;
@@ -1610,10 +1610,10 @@ void KBgEngineFIBS::handleMessageNewLogin(const TQString &line)
TQString text = i18n("Your account has been created. Your new login is <u>%1</u>. To fully activate "
"this account, I will now close the connection. Once you reconnect, you can start "
- "playing backgammon on FIBS.").tqarg(infoFIBS[FIBSUser]);
+ "playing backgammon on FIBS.").arg(infoFIBS[FIBSUser]);
emit infoText("<br><hr><font color=\"blue\">" + text + "</font><br><hr>");
emit serverString("bye");
- rxtqStatus = RxNormal;
+ rxStatus = RxNormal;
rxCollect = "";
return;
}
@@ -1717,7 +1717,7 @@ void KBgEngineFIBS::handleMessageNormal(TQString &line, TQString &rawline)
/*
* Save the board string and create a new game state
*/
- KBgtqStatus *st = new KBgtqStatus(currBoard = rawline);
+ KBgStatus *st = new KBgStatus(currBoard = rawline);
/*
* Save important state data and stop the timeout
@@ -1736,15 +1736,15 @@ void KBgEngineFIBS::handleMessageNormal(TQString &line, TQString &rawline)
* Update the caption string
*/
if (st->turn() < 0)
- caption = i18n("%1 (%2) vs. %3 (%4) - game over").tqarg(pname[US]).
- tqarg(st->points(US)).tqarg(pname[THEM]).tqarg(st->points(THEM));
+ caption = i18n("%1 (%2) vs. %3 (%4) - game over").arg(pname[US]).
+ arg(st->points(US)).arg(pname[THEM]).arg(st->points(THEM));
else if (st->length() < 0)
- caption = i18n("%1 (%2) vs. %3 (%4) - unlimited match").tqarg(pname[US]).
- tqarg(st->points(US)).tqarg(pname[THEM]).tqarg(st->points(THEM));
+ caption = i18n("%1 (%2) vs. %3 (%4) - unlimited match").arg(pname[US]).
+ arg(st->points(US)).arg(pname[THEM]).arg(st->points(THEM));
else
- caption = i18n("%1 (%2) vs. %3 (%4) - %5 point match").tqarg(pname[US]).
- tqarg(st->points(US)).tqarg(pname[THEM]).tqarg(st->points(THEM)).
- tqarg(st->length());
+ caption = i18n("%1 (%2) vs. %3 (%4) - %5 point match").arg(pname[US]).
+ arg(st->points(US)).arg(pname[THEM]).arg(st->points(THEM)).
+ arg(st->length());
emit statText(caption);
@@ -1779,13 +1779,13 @@ void KBgEngineFIBS::handleMessageNormal(TQString &line, TQString &rawline)
*/
else if (line.contains(pat[YouAway])) {
- emit changePlayertqStatus(infoFIBS[FIBSUser], KFibsPlayerList::Away, true);
+ emit changePlayerStatus(infoFIBS[FIBSUser], KFibsPlayerList::Away, true);
actBack->setEnabled(true);
line += "<br><pre> </pre>" + i18n("(or use the corresponding menu entry to join the match)");
}
else if (line.contains(pat[YouBack])) {
- emit changePlayertqStatus(infoFIBS[FIBSUser], KFibsPlayerList::Away, false);
+ emit changePlayerStatus(infoFIBS[FIBSUser], KFibsPlayerList::Away, false);
actBack->setEnabled(false);
actAway->setEnabled(true);
}
@@ -1863,23 +1863,23 @@ void KBgEngineFIBS::handleMessageNormal(TQString &line, TQString &rawline)
// - rx status changes ------------------------------------------------------------
else if (line.contains(pat[WhoisBG])) {
- rxtqStatus = RxWhois;
+ rxStatus = RxWhois;
rxCollect = TQString("<br><u>") + line + "</u>";
return;
}
else if (line.contains(pat[MotdBeg])) {
- rxtqStatus = RxMotd;
+ rxStatus = RxMotd;
rxCollect = "";
return;
}
else if (line.contains(pat[BegRate])) {
- rxtqStatus = RxRating;
+ rxStatus = RxRating;
rxCount = 0;
rxCollect = "<br>" + line;
return;
}
else if (line.contains(pat[Goodbye])) {
- rxtqStatus = RxGoodbye;
+ rxStatus = RxGoodbye;
rxCollect = "<br><hr><br>";
handleServerData(rawline); // danger: recursion!
return;
@@ -1944,13 +1944,13 @@ void KBgEngineFIBS::handleMessageNormal(TQString &line, TQString &rawline)
else if (line.contains(pat[BegBlnd])) {
rawline.replace(pat[BegBlnd], "");
rawline.truncate(rawline.length()-1);
- emit changePlayertqStatus(rawline, KFibsPlayerList::Blind, true);
+ emit changePlayerStatus(rawline, KFibsPlayerList::Blind, true);
line = "<font color=\"red\">" + line + "</font>";
}
else if (line.contains(pat[EndBlnd])) {
rawline.replace(pat[EndBlnd], "");
rawline.truncate(rawline.length()-1);
- emit changePlayertqStatus(rawline, KFibsPlayerList::Blind, false);
+ emit changePlayerStatus(rawline, KFibsPlayerList::Blind, false);
line = "<font color=\"red\">" + line + "</font>";
}
/*
@@ -2128,8 +2128,8 @@ KBgEngineFIBS::KBgEngineFIBS(TQWidget *parent, TQString *name, TQPopupMenu *pmen
connect(this, TQT_SIGNAL(fibsLogout (const TQString &)), playerlist, TQT_SLOT(deletePlayer(const TQString &)));
connect(this, TQT_SIGNAL(fibsWhoEnd()), playerlist, TQT_SLOT(stopUpdate()));
connect(this, TQT_SIGNAL(fibsConnectionClosed()), playerlist, TQT_SLOT(stopUpdate()));
- connect(this, TQT_SIGNAL(changePlayertqStatus(const TQString &, int, bool)),
- playerlist, TQT_SLOT(changePlayertqStatus(const TQString &, int, bool)));
+ connect(this, TQT_SIGNAL(changePlayerStatus(const TQString &, int, bool)),
+ playerlist, TQT_SLOT(changePlayerStatus(const TQString &, int, bool)));
connect(playerlist, TQT_SIGNAL(fibsCommand(const TQString &)), this, TQT_SLOT(handleCommand(const TQString &)));
connect(playerlist, TQT_SIGNAL(fibsInvite(const TQString &)), this, TQT_SLOT(fibsRequestInvitation(const TQString &)));